@@ -3,7 +3,7 @@
  Copyright(c) 2014 Jasem Mutlaq. All rights reserved.
 
  The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi.
- The transformations are based on the paper Matrix Method for Coodinates Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
+ The transformations are based on the paper Matrix Method for Coordinates Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
@@ -23,8 +23,8 @@
 #pragma once
 
 #include "defaultdevice.h"
-
-#include <libnova/ln_types.h>
+#include "libastro.h"
+#include "inditimer.h"
 
 #include <string>
 
@@ -63,7 +63,7 @@ class TCP;
 
    Developers need to subclass INDI::Dome to implement any driver for Domes within INDI.
 
-  \note The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi. The transformations are based on the paper Matrix Method for Coodinates
+  \note The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi. The transformations are based on the paper Matrix Method for Coordinates
  Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
 
 \author Jasem Mutlaq
@@ -155,9 +155,9 @@ class Dome : public DefaultDevice
         {
             DOME_CAN_ABORT          = 1 << 0, /*!< Can the dome motion be aborted? */
             DOME_CAN_ABS_MOVE       = 1 << 1, /*!< Can the dome move to an absolute azimuth position? */
-            DOME_CAN_REL_MOVE       = 1 << 2, /*!< Can the dome move to a relative position a number of degrees away from current position? Positive degress is Clockwise direction. Negative Degrees is counter clock wise direction */
+            DOME_CAN_REL_MOVE       = 1 << 2, /*!< Can the dome move to a relative position a number of degrees away from current position? Positive degrees is Clockwise direction. Negative Degrees is counter clock wise direction */
             DOME_CAN_PARK           = 1 << 3, /*!< Can the dome park and unpark itself? */
-            DOME_CAN_SYNC           = 1 << 4, /*!< Can the dome sync to arbitrary postion? */
+            DOME_CAN_SYNC           = 1 << 4, /*!< Can the dome sync to arbitrary position? */
             DOME_HAS_SHUTTER        = 1 << 5, /*!< Does the dome has a shutter than can be opened and closed electronically? */
             DOME_HAS_VARIABLE_SPEED = 1 << 6, /*!< Can the dome move in different configurable speeds? */
             DOME_HAS_BACKLASH       = 1 << 7  /*!< Can the dome compensate for backlash? */
@@ -176,16 +176,15 @@ class Dome : public DefaultDevice
         Dome();
         virtual ~Dome();
 
-        virtual bool initProperties();
-        virtual void ISGetProperties(const char * dev);
-        virtual bool updateProperties();
-        virtual bool ISNewNumber(const char * dev, const char * name, double values[], char * names[], int n);
-        virtual bool ISNewSwitch(const char * dev, const char * name, ISState * states, char * names[], int n);
-        virtual bool ISNewText(const char * dev, const char * name, char * texts[], char * names[], int n);
-        virtual bool ISSnoopDevice(XMLEle * root);
+        virtual bool initProperties() override;
+        virtual void ISGetProperties(const char * dev) override;
+        virtual bool updateProperties() override;
+        virtual bool ISNewNumber(const char * dev, const char * name, double values[], char * names[], int n) override;
+        virtual bool ISNewSwitch(const char * dev, const char * name, ISState * states, char * names[], int n) override;
+        virtual bool ISNewText(const char * dev, const char * name, char * texts[], char * names[], int n) override;
+        virtual bool ISSnoopDevice(XMLEle * root) override;
 
         static void buttonHelper(const char * button_n, ISState state, void * context);
-        static void updateMountCoordsHelper(void *context);
 
         /**
              * @brief setDomeConnection Set Dome connection mode. Child class should call this in the constructor before Dome registers
@@ -222,7 +221,7 @@ class Dome : public DefaultDevice
         }
 
         /**
-             * @return True if dome has absolute postion encoders.
+             * @return True if dome has absolute position encoders.
              */
         bool CanAbsMove()
         {
@@ -421,13 +420,13 @@ class Dome : public DefaultDevice
 
         /**
              * @brief SetRAPark Set current AZ parking position. The data park file (stored in ~/.indi/ParkData.xml) is updated in the process.
-             * @param value current Axis 1 value (AZ either in angles or encoder values as specificed by the DomeParkData type).
+             * @param value current Axis 1 value (AZ either in angles or encoder values as specified by the DomeParkData type).
              */
         void SetAxis1Park(double value);
 
         /**
              * @brief SetAxis1Park Set default AZ parking position.
-             * @param value Default Axis 1 value (AZ either in angles or encoder values as specificed by the DomeParkData type).
+             * @param value Default Axis 1 value (AZ either in angles or encoder values as specified by the DomeParkData type).
              */
         void SetAxis1ParkDefault(double steps);
 
@@ -506,7 +505,7 @@ class Dome : public DefaultDevice
              * @param fp pointer to configuration file
              * @return true if successful, false otherwise.
              */
-        virtual bool saveConfigItems(FILE * fp);
+        virtual bool saveConfigItems(FILE * fp) override;
 
         /**
              * @brief updateCoords updates the horizontal coordinates (Az & Alt) of the mount from the snooped RA, DEC and observer's location.
@@ -586,12 +585,25 @@ class Dome : public DefaultDevice
         ISwitchVectorProperty PresetGotoSP;
         INumber DomeMeasurementsN[6];
         INumberVectorProperty DomeMeasurementsNP;
+
         ISwitchVectorProperty OTASideSP;
-        ISwitch OTASideS[2];
+        ISwitch OTASideS[5];
+        // 0 is East, 1 is West, 2 is as reported by mout, 3 as deducted by Hour Angle
+        // 4 ignore pier side and perform as in a fork mount
+        enum
+        {
+            DM_OTA_SIDE_EAST,
+            DM_OTA_SIDE_WEST,
+            DM_OTA_SIDE_MOUNT,
+            DM_OTA_SIDE_HA,
+            DM_OTA_SIDE_IGNORE
+        };
+
+        int mountOTASide = 0; // Side of the telescope with respect of the mount, 1: west, -1: east, 0 not reported
         ISwitchVectorProperty DomeAutoSyncSP;
         ISwitch DomeAutoSyncS[2];
 
-        // Backlash toogle
+        // Backlash toggle
         ISwitchVectorProperty DomeBacklashSP;
         ISwitch DomeBacklashS[2];
 
@@ -613,13 +625,13 @@ class Dome : public DefaultDevice
         IPState m_MountState;
 
         // Observer geographic coords. Snooped from mount driver.
-        struct ln_lnlat_posn observer;
+        IGeographicCoordinates observer;
         // Do we have valid geographic coords from mount driver?
         bool HaveLatLong = false;
 
         // Mount horizontal and equatorial coords. Snoops from mount driver.
-        struct ln_hrz_posn mountHoriztonalCoords;
-        struct ln_equ_posn mountEquatorialCoords;
+        INDI::IHorizontalCoordinates mountHoriztonalCoords;
+        INDI::IEquatorialCoordinates mountEquatorialCoords;
         // Do we have valid coords from mount driver?
         bool HaveRaDec = false;
 
@@ -650,10 +662,12 @@ class Dome : public DefaultDevice
         bool IsMountParked = false;
         bool IsLocked = true;
         bool AutoSyncWarning = false;
+        bool UseHourAngle = false;
 
         const char * ParkDeviceName;
         const std::string ParkDataFileName;
-        int m_HorizontalUpdateTimerID { -1 };
+        INDI::Timer m_MountUpdateTimer;
+        //int m_HorizontalUpdateTimerID { -1 };
         XMLEle * ParkdataXmlRoot, *ParkdeviceXml, *ParkstatusXml, *ParkpositionXml, *ParkpositionAxis1Xml;
 
         double Axis1ParkPosition;
