@@ -21,9 +21,6 @@
 #include "indiapi.h"
 #include "indidevapi.h"
 #include "indiwidgettraits.h"
-
-#include "indidriver.h" // IUSaveConfigXXX (indicom.c)
-
 #include "indiwidgetview.h"
 
 #include <string>
@@ -38,6 +35,18 @@ namespace INDI
 template <typename> struct WidgetView;
 template <typename> struct PropertyView;
 
+typedef PropertyView<IText>   PropertyViewText;
+typedef PropertyView<INumber> PropertyViewNumber;
+typedef PropertyView<ISwitch> PropertyViewSwitch;
+typedef PropertyView<ILight>  PropertyViewLight;
+typedef PropertyView<IBLOB>   PropertyViewBlob;
+
+typedef WidgetView<IText>     WidgetViewText;
+typedef WidgetView<INumber>   WidgetViewNumber;
+typedef WidgetView<ISwitch>   WidgetViewSwitch;
+typedef WidgetView<ILight>    WidgetViewLight;
+typedef WidgetView<IBLOB>     WidgetViewBlob;
+
 #define PROPERTYVIEW_BASE_ACCESS public
 // don't use direct access to low-level property
 //#define PROPERTYVIEW_BASE_ACCESS protected // future
@@ -49,22 +58,22 @@ template <typename> struct PropertyView;
  * INDI::PropertyView
  *
  * A class that will allow a easy transition to the new widget handling interface (future).
- * - Use PropertyView<IText>   instead of ITextVectorProperty
- * - Use PropertyView<INumber> instead of INumberVectorProperty
- * - Use PropertyView<ISwitch> instead of ISwitchVectorProperty
- * - Use PropertyView<ILight>  instead of ILightVectorProperty
- * - Use PropertyView<IBLOB>   instead of IBLOBVectorProperty
+ * - Use PropertyViewText   instead of ITextVectorProperty
+ * - Use PropertyViewNumber instead of INumberVectorProperty
+ * - Use PropertyViewSwitch instead of ISwitchVectorProperty
+ * - Use PropertyViewLight  instead of ILightVectorProperty
+ * - Use PropertyViewBlob   instead of IBLOBVectorProperty
  *
  * The PropertyView<IXXX> class is compatible with low-level IXXXVectorProperty structures.
  *
  * INDI::WidgetView
  *
  * A class that will allow a easy transition to the new widget handling interface (future).
- * - Use WidgetView<IText>   instead of IText
- * - Use WidgetView<INumber> instead of INumber
- * - Use WidgetView<ISwitch> instead of ISwitch
- * - Use WidgetView<ILight>  instead of ILight
- * - Use WidgetView<IBLOB>   instead of IBLOB
+ * - Use WidgetViewText   instead of IText
+ * - Use WidgetViewNumber instead of INumber
+ * - Use WidgetViewSwitch instead of ISwitch
+ * - Use WidgetViewLight  instead of ILight
+ * - Use WidgetViewBlob   instead of IBLOB
  *
  * The WidgetView<IXXX> class is compatible with low-level IXXX structures.
  */
@@ -222,6 +231,7 @@ struct PropertyView: PROPERTYVIEW_BASE_ACCESS WidgetTraits<T>::PropertyType
         }
 
     public: // only driver side
+        bool load();
         void save(FILE *f) const;                              /* outside implementation */
 
         void vapply(const char *format, va_list args)
@@ -323,6 +333,15 @@ struct PropertyView: PROPERTYVIEW_BASE_ACCESS WidgetTraits<T>::PropertyType
             //free(widget()); // #PS: do not delete items, they may be on the stack.
             memset(this, 0, sizeof(*this));
         }
+    public: // internal use only
+        static PropertyView<T> *cast(PropertyType *raw)
+        {
+            return static_cast<PropertyView<T>*>(raw);
+        }
+        PropertyType *cast()
+        {
+            return this;
+        }
 };
 
 template <typename>
@@ -380,7 +399,7 @@ struct WidgetView<IText>: PROPERTYVIEW_BASE_ACCESS IText
 
         void setName(const char *name)
         {
-            strncpy(this->name, name, MAXINDINAME);
+            INDI::strlcpy(this->name, name);
         }
         void setName(const std::string &name)
         {
@@ -389,7 +408,7 @@ struct WidgetView<IText>: PROPERTYVIEW_BASE_ACCESS IText
 
         void setLabel(const char *label)
         {
-            strncpy(this->label, label, MAXINDILABEL);
+            INDI::strlcpy(this->label, label);
         }
         void setLabel(const std::string &label)
         {
@@ -399,8 +418,7 @@ struct WidgetView<IText>: PROPERTYVIEW_BASE_ACCESS IText
         //void setText(const char *text)                         { free(this->text); this->text = strndup(text, strlen(text)); }
         void setText(const char *text, size_t size)
         {
-            this->text = strncpy(static_cast<char*>(realloc(this->text, size + 1)), text, size);
-            this->text[size] = '\0';
+            INDI::strlcpy(this->text = static_cast<char*>(realloc(this->text, size + 1)), text, size + 1);
         }
         void setText(const char *text)
         {
@@ -428,7 +446,7 @@ struct WidgetView<IText>: PROPERTYVIEW_BASE_ACCESS IText
         }
         const char *getText()  const
         {
-            return this->text;
+            return this->text ? this->text : "";
         }
 
         void *getAux() const
@@ -454,6 +472,11 @@ struct WidgetView<IText>: PROPERTYVIEW_BASE_ACCESS IText
         {
             return getLabel() == otherLabel;
         }
+        
+        bool isEmpty() const
+        {
+            return getText()[0] == '\0';
+        }
 
     public:
         void fill(const char *name, const char *label, const char *initialText)
@@ -509,7 +532,7 @@ struct WidgetView<INumber>: PROPERTYVIEW_BASE_ACCESS INumber
 
         void setName(const char *name)
         {
-            strncpy(this->name, name, MAXINDINAME);
+            INDI::strlcpy(this->name, name);
         }
         void setName(const std::string &name)
         {
@@ -518,7 +541,7 @@ struct WidgetView<INumber>: PROPERTYVIEW_BASE_ACCESS INumber
 
         void setLabel(const char *label)
         {
-            strncpy(this->label, label, MAXINDILABEL);
+            INDI::strlcpy(this->label, label);
         }
         void setLabel(const std::string &label)
         {
@@ -527,7 +550,7 @@ struct WidgetView<INumber>: PROPERTYVIEW_BASE_ACCESS INumber
 
         void setFormat(const char *format)
         {
-            strncpy(this->format, format, MAXINDIFORMAT);
+            INDI::strlcpy(this->format, format);
         }
         void setFormat(const std::string &format)
         {
@@ -673,7 +696,7 @@ struct WidgetView<ISwitch>: PROPERTYVIEW_BASE_ACCESS ISwitch
 
         void setName(const char *name)
         {
-            strncpy(this->name, name, MAXINDINAME);
+            INDI::strlcpy(this->name, name);
         }
         void setName(const std::string &name)
         {
@@ -682,7 +705,7 @@ struct WidgetView<ISwitch>: PROPERTYVIEW_BASE_ACCESS ISwitch
 
         void setLabel(const char *label)
         {
-            strncpy(this->label, label, MAXINDILABEL);
+            INDI::strlcpy(this->label, label);
         }
         void setLabel(const std::string &label)
         {
@@ -802,7 +825,7 @@ struct WidgetView<ILight>: PROPERTYVIEW_BASE_ACCESS ILight
 
         void setName(const char *name)
         {
-            strncpy(this->name, name, MAXINDINAME);
+            INDI::strlcpy(this->name, name);
         }
         void setName(const std::string &name)
         {
@@ -811,7 +834,7 @@ struct WidgetView<ILight>: PROPERTYVIEW_BASE_ACCESS ILight
 
         void setLabel(const char *label)
         {
-            strncpy(this->label, label, MAXINDILABEL);
+            INDI::strlcpy(this->label, label);
         }
         void setLabel(const std::string &label)
         {
@@ -931,7 +954,7 @@ struct WidgetView<IBLOB>: PROPERTYVIEW_BASE_ACCESS IBLOB
 
         void setName(const char *name)
         {
-            strncpy(this->name, name, MAXINDINAME);
+            INDI::strlcpy(this->name, name);
         }
         void setName(const std::string &name)
         {
@@ -940,7 +963,7 @@ struct WidgetView<IBLOB>: PROPERTYVIEW_BASE_ACCESS IBLOB
 
         void setLabel(const char *label)
         {
-            strncpy(this->label, label, MAXINDILABEL);
+            INDI::strlcpy(this->label, label);
         }
         void setLabel(const std::string &label)
         {
@@ -949,11 +972,11 @@ struct WidgetView<IBLOB>: PROPERTYVIEW_BASE_ACCESS IBLOB
 
         void setFormat(const char *format)
         {
-            strncpy(this->format, format, MAXINDIBLOBFMT);
+            INDI::strlcpy(this->format, format);
         }
         void setFormat(const std::string &format)
         {
-            setLabel(format.data());
+            setFormat(format.data());
         }
 
         void setBlob(void *blob)
@@ -988,11 +1011,18 @@ struct WidgetView<IBLOB>: PROPERTYVIEW_BASE_ACCESS IBLOB
         {
             return this->format;
         }
-
+        void *getBlob()
+        {
+            return this->blob;
+        }
         const void *getBlob()   const
         {
             return this->blob;
         }
+        std::string getBlobAsString() const
+        {
+            return std::string(static_cast<const char*>(this->blob), this->bloblen);
+        }
         int getBlobLen() const
         {
             return this->bloblen;
@@ -1034,6 +1064,16 @@ struct WidgetView<IBLOB>: PROPERTYVIEW_BASE_ACCESS IBLOB
         {
             fill(name.c_str(), label.c_str(), format.c_str());
         }
+
+    public: // internal use only
+        static WidgetView<Type> *cast(Type *blob)
+        {
+            return static_cast<WidgetView<Type>*>(blob);
+        }
+        Type *cast()
+        {
+            return this;
+        }
 };
 
 
@@ -1049,7 +1089,7 @@ inline PropertyView<T>::PropertyView()
 template <typename T>
 inline void PropertyView<T>::setDeviceName(const char *name)
 {
-    strncpy(this->device, name, MAXINDIDEVICE);
+    INDI::strlcpy(this->device, name);
 }
 
 template <typename T>
@@ -1061,7 +1101,7 @@ inline void PropertyView<T>::setDeviceName(const std::string &name)
 template <typename T>
 inline void PropertyView<T>::setName(const char *name)
 {
-    strncpy(this->name, name, MAXINDINAME);
+    INDI::strlcpy(this->name, name);
 }
 
 template <typename T>
@@ -1073,7 +1113,7 @@ inline void PropertyView<T>::setName(const std::string &name)
 template <typename T>
 inline void PropertyView<T>::setLabel(const char *label)
 {
-    strncpy(this->label, label, MAXINDILABEL);
+    INDI::strlcpy(this->label, label);
 }
 
 template <typename T>
@@ -1085,7 +1125,7 @@ inline void PropertyView<T>::setLabel(const std::string &label)
 template <typename T>
 inline void PropertyView<T>::setGroupName(const char *name)
 {
-    strncpy(this->group, name, MAXINDIGROUP);
+    INDI::strlcpy(this->group, name);
 }
 
 template <typename T>
@@ -1103,7 +1143,7 @@ inline void PropertyView<T>::setState(IPState state)
 template <typename T>
 inline void PropertyView<T>::setTimestamp(const char *timestamp)
 {
-    strncpy(this->timestamp, timestamp, MAXINDITSTAMP);
+    INDI::strlcpy(this->timestamp, timestamp);
 }
 
 template <typename T>
@@ -1126,9 +1166,33 @@ inline void PropertyView<T>::setAux(void *user)
 }
 
 template <>
-inline void PropertyView<IText>::save(FILE *f) const
+inline bool PropertyView<INumber>::load()
 {
-    IUSaveConfigText(f, this);
+    return IULoadConfigNumber(this) == nnp;
+}
+
+template <>
+inline bool PropertyView<ISwitch>::load()
+{
+    return IULoadConfigSwitch(this) == nsp;
+}
+
+template <>
+inline bool PropertyView<ILight>::load()
+{
+    return false;
+}
+
+template <>
+inline bool PropertyView<IBLOB>::load()
+{
+    return false;
+}
+
+template <>
+inline bool PropertyView<IText>::load()
+{
+    return IULoadConfigText(this) == ntp;
 }
 
 template <>
@@ -1137,6 +1201,12 @@ inline void PropertyView<INumber>::save(FILE *f) const
     IUSaveConfigNumber(f, this);
 }
 
+template <>
+inline void PropertyView<IText>::save(FILE *f) const
+{
+    IUSaveConfigText(f, this);
+}
+
 template <>
 inline void PropertyView<ISwitch>::save(FILE *f) const
 {
@@ -1273,35 +1343,35 @@ template <>
 inline void PropertyView<IText>::setWidgets(WidgetType *w, size_t size)
 {
     this->tp = w;
-    this->ntp = size;
+    this->ntp = int(size);
 }
 
 template <>
 inline void PropertyView<INumber>::setWidgets(WidgetType *w, size_t size)
 {
     this->np = w;
-    this->nnp = size;
+    this->nnp = int(size);
 }
 
 template <>
 inline void PropertyView<ISwitch>::setWidgets(WidgetType *w, size_t size)
 {
     this->sp = w;
-    this->nsp = size;
+    this->nsp = int(size);
 }
 
 template <>
 inline void PropertyView<ILight>::setWidgets(WidgetType *w, size_t size)
 {
     this->lp = w;
-    this->nlp = size;
+    this->nlp = int(size);
 }
 
 template <>
 inline void PropertyView<IBLOB>::setWidgets(WidgetType *w, size_t size)
 {
     this->bp = w;
-    this->nbp = size;
+    this->nbp = int(size);
 }
 
 template <>
